@font-face {
	font-family: 'open_sans';
	src: url('../versionupgrade/fonts/opensans-regular-webfont.eot');
	src: url('../versionupgrade/fonts/opensans-regular-webfont.eot?#iefix') format('embedded-opentype'),
				url('../versionupgrade/fonts/opensans-regular-webfont.woff') format('woff'),
				url('../versionupgrade/fonts/opensans-regular-webfont.ttf') format('truetype');
	font-weight: normal;
	font-style: normal;
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;
}
@font-face {
	font-family: 'open_sans';
	src: url('../versionupgrade/fonts/opensans-bold-webfont.eot');
	src: url('../versionupgrade/fonts/opensans-bold-webfont.eot?#iefix') format('embedded-opentype'),
			url('../versionupgrade/fonts/opensans-bold-webfont.woff') format('woff'),
			url('../versionupgrade/fonts/opensans-bold-webfont.ttf') format('truetype');
	font-weight: 700;
	font-style: normal;
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;
}

#versionupgrade {
	font-family: 'open_sans' !important;
	.jumbotron {
		border-radius: 6px;
		@media screen and (min-width: 768px) {
			padding-top: 20px;
			padding-bottom: 20px;
		}
		p {
			margin-bottom: 10px;
		}
		.panel-group {
			.feature {
				margin-bottom: 2px;
				.panel-body {
					padding: 8px;
				}
				.panel-title {
					font-size: 13px;
				}
				p {
					font-size: 13px;
					text-align: center;
				}
			}
		}
	}
	.btn {
		border: 1px solid rgba(116,178,226,0.46);
		background: #d7ebf9;
		color: #0070a3;
		display: inline-block;
		position: relative;
		line-height: 1.42857143;
		touch-action: manipulation;
		cursor: pointer;
		vertical-align: middle;
		text-align: center;
		overflow: visible;
		font-size: 14px !important;
		padding: 5px 18px;
		font-weight: bold;
		height: 31px;
		min-width: 45px;
		margin: 0;
		margin-right: 5px;
		white-space: nowrap;
		border-radius: 6px;
	}
	.btn:hover {
		border: 1px solid rgba(116,178,226,0.46);
		background: #d7ebf9;
		color: #0070a3;
		background-color: #EBF7FF;
	}
	.btn:active {
		border: 1px solid rgba(116,178,226,0.46);
		background: #d7ebf9;
		color: #FFFFFF;
		background-color: #358BC8;
	}
	.green {
		color: green;
	}
	.yellow {
		color: yellow;
	}
	.red {
		color: red;
	}
	.alert {
		width: 100%;
	}
}

.form-group {
	label {
		font-weight: bold;
	}
}

#upgradeModal .modal-body .body {
	word-wrap: break-word;
	height: 193px;
	overflow-y: auto;
}
#upgradeModal {
	.modal-dialog {
		width: 800px;
	}
}
.progress-bar.active, .progress.active .progress-bar {
    -webkit-animation: progress-bar-stripes 2s linear infinite;
    -o-animation: progress-bar-stripes 2s linear infinite;
    animation: progress-bar-stripes 2s linear infinite;
}
.progress-bar-striped, .progress-striped .progress-bar {
    background-image: -webkit-linear-gradient(45deg,rgba(255,255,255,.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,.15) 50%,rgba(255,255,255,.15) 75%,transparent 75%,transparent);
    background-image: -o-linear-gradient(45deg,rgba(255,255,255,.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,.15) 50%,rgba(255,255,255,.15) 75%,transparent 75%,transparent);
    background-image: linear-gradient(45deg,rgba(255,255,255,.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,.15) 50%,rgba(255,255,255,.15) 75%,transparent 75%,transparent);
    -webkit-background-size: 40px 40px;
    background-size: 40px 40px;
}

.modal-body.swMain {
	float: none;
	border-bottom-left-radius: 6px;
	border-bottom-right-radius: 6px;
	.actionBar {
		display: none;
		-webkit-border-radius: 0px;
		-moz-border-radius: 0px;
		border: none;
		border-top: 1px solid #ccc;
		border-bottom-left-radius: 6px;
		border-bottom-right-radius: 6px;
	}
}
.modal-footer {
	padding: 9px 20px 9px;
}

#post-message {
	font-weight: bold;
	font-size: 150%;
	margin-top: 20px;
	text-align: center;
}
